.TH "YODL macros" "7" "1996" "YODL" "YODL" 
.PP 
.SH "NAME yodlmacros \- Macros for the YODL converters" 
.SH "SYNOPSIS" 
This manual page lists the macros of the YODL package\&.
.SH "DESCRIPTION" 
The following list shows the macros that the YODL converters 
define and which can be used in YODL documents\&. Refer the long
YODL user guide, distributed with the YODL package, for a full 
description\&. 
.PP 
.IP "\f(CWabstract(text)\fP" 
Defines an abstract for an \f(CWarticle\fP or \f(CWreport\fP document\&. Abstracts are
not implemented for \f(CWbook\fPs or \f(CWmanpage\fPs\&. Must appear \fBbefore\fP
starting the document with the \f(CWarticle\fP or \f(CWreport\fP macro\&.
.IP "\f(CWaffiliation(site)\fP" 
Defines an affiliation, to appear in the document titlepage below the
author field\&. Must appear \fBbefore\fP starting the document with
\f(CWarticle\fP, \f(CWreport\fP or \f(CWbook\fP\&. The affiliation is only printed when the
author field is not empty\&.
.IP "\f(CWarticle(title)(author)(date)\fP" 
Starts an article\&. The top-level sectioning command is \f(CW(n)sect\fP\&. In HTML
conversions only one output file is written\&.
.IP "\f(CWbf(text)\fP" 
Sets \f(CWtext\fP in boldface\&.
.IP "\f(CWbook(title)(author)(date)\fP" 
Starts a book document\&. The top-level sectioning command is \f(CW(n)chapter\fP,
\f(CW(n)part\fP being optional\&. In HTML output files are created for each
chapter\&.
.IP "\f(CWcenter(text)\fP" 
Sets \f(CWtext\fP centered, when the output format permits\&. Use \f(CWnl()\fP in the
text to break lines\&.
.IP "\f(CWchapter(title)\fP" 
Starts a new chapter in \f(CWbook\fPs or \f(CWreport\fPs\&.
.IP "\f(CWclearpage()\fP" 
Starts a new page, when the output format permits\&. Under HTML a horizontal
line is drawn\&.
.IP "\f(CWdef(macroname)(nrofargs)(redefinition)\fP" 
Defines \f(CWmacroname\fP as a macro, having \f(CWnrofargs\fP arguments, and
expanding to \f(CWredefinition\fP\&. This macro is a shorthand for 
\f(CWDEFINEMACRO\fP\&. An error occurs when the macro is already defined\&. Use
\f(CWredef()\fP to unconditionally define or redefine a macro\&.
.IP "\f(CWdescription(list)\fP" 
Sets \f(CWlist\fP as a description list\&. Use \f(CWdit(item)\fP to
indicate items in the list\&.
.IP "\f(CWdit(itemname)\fP" 
Starts an item named \f(CWitemname\fP in a descriptive list\&. The list is either
enclosed by \f(CWstartdit()\fP and \f(CWenddit()\fP, or is an argument to
\f(CWdescription()\fP\&.
.IP "\f(CWeit()\fP" 
Indicates an item in an enumerated list\&. The list is either enclosed by
\f(CWstarteit()\fP and \f(CWendeit()\fP, or is an argument to \f(CWenumerate()\fP\&.
.IP "\f(CWem(text)\fP" 
Sets \f(CWtext\fP as emphasized, usually italics\&.
.IP "\f(CWendcenter()\fP" 
Ends centered text that is started with \f(CWstartcenter()\fP\&.
.IP "\f(CWenddit()\fP" 
Ends a descriptive list that is started with \f(CWstartdit()\fP\&.
.IP "\f(CWendeit()\fP" 
Ends an enumerated list that is started with \f(CWstarteit()\fP\&.
.IP "\f(CWendit()\fP" 
Ends an itemized list that is started with \f(CWstartit()\fP\&.
.IP "\f(CWenumerate(list)\fP" 
Sets \f(CWlist\fP as an enumerated list\&. Use \f(CWeit()\fP to indicate items in
the list\&.
.IP "\f(CWfootnote(text)\fP" 
Sets \f(CWtext\fP as a footnote, or in parentheses when the output format
does not allow footnotes\&.
.IP "\f(CWgagmacrowarning(name name \&.\&.\&.)\fP" 
Prevents the \f(CWyodl\fP program from printing \fIcannot expand possible user
macro\fP\&. E\&.g\&., if you have in your document \f(CWthe file(s) are \&.\&.\fP then you
might want to put at before that \f(CWgagmacrowarning(file)\fP\&. Shorthand for
\f(CWNOUSERMACRO\fP\&.
.IP "\f(CWhtmlbodyopt(option)(value)\fP" 
Adds \f(CWoption="value"\fP to the options of the \f(CW<body \&.\&.\&.>\fP tag in HTML 
files\&. Useful options are, e\&.g\&., \f(CWfgcolor\fP and \f(CWbgcolor\fP, whose values 
are expressed as \f(CW#rrggbb\fP, where \f(CWrr\fP are two hexadecimal digits of 
the red component, \f(CWgg\fP two hexadecimal digits of the green component, 
and \f(CWbb\fP two hexadecimal digits of the blue component\&.
.IP "\f(CWhtmlcommand(cmd)\fP" 
Sets \f(CWcmd\fP when converting to HTML\&. The \f(CWcmd\fP is not further parsed 
by YODL\&.
.IP "\f(CWhtmltag(tagname)(start)\fP" 
Sets \f(CWtagname\fP as a HTML tag, enclosed by \f(CW<\fP and \f(CW>\fP\&. When
\f(CWstart\fP is zero, the \f(CWtagname\fP is prefixed with \f(CW/\fP\&.
.IP "\f(CWincludefile(file)\fP" 
Includes \f(CWfile\fP and defines a label with the same name\&. The default
extension \f(CW\&.yo\fP is supplied if necessary\&.
.IP "\f(CWit()\fP" 
Indicates an item in an itemized list\&. The list is either surrounded by
\f(CWstartit()\fP and \f(CWendit()\fP, or it is an argument to \f(CWitemize()\fP\&.
.IP "\f(CWitemize(list)\fP" 
Sets \f(CWlist\fP as an itemized list\&. Use \f(CWit()\fP to indicate items in the
list\&.
.IP "\f(CWlabel(labelname)\fP" 
Defines \f(CWlabelname\fP as an anchor for a \f(CWlink\fP
command, or to stand for the last numbering of a section or figure in a
\f(CWref\fP command\&.
.IP "\f(CWlatexcommand(cmd)\fP" 
Writes \f(CWcmd\fP to the output when converting to LaTeX\&. The \f(CWcmd\fP is not 
further expanded by YODL\&.
.IP "\f(CWlatexoptions(options)\fP" 
Sets the LaTeX processing options, a useful option is, e\&.g\&.,
\f(CWdina4,epsf\fP\&. This command \fBmust\fP appear before the document type is
stated by \f(CWarticle\fP, \f(CWreport\fP, etc\&.\&.
.IP "\f(CWlink(description)(labelname)\fP" 
In HTML output a clickable link with the text \f(CWdescription\fP is created that
points to the place where \f(CWlabelname\fP is defined using the \f(CWlabel\fP macro\&.
Using \f(CWlink\fP is similar to \f(CWurl\fP, except that a hyperlink
is set pointing to a location in the same document\&. For output formats other
than HTML, only the \f(CWdescription\fP appears\&.
.IP "\f(CWmailto(address)\fP" 
Defines the default \f(CWmailto\fP address for HTML output\&. Must appear
\fBbefore\fP the document type is stated by \f(CWarticle\fP, \f(CWreport\fP, etc\&.\&.
.IP "\f(CWmancommand(cmd)\fP" 
Writes \f(CWcmd\fP to the output when converting to man\&. The \f(CWcmd\fP is not 
further expanded by YODL\&.
.IP "\f(CWmanpage(title)(section)(date)(source)(manual)\fP" 
Starts a manual page document\&. The \f(CWsection\fP argument must be a number,
stating to which section the manpage belongs to\&. Most often used are commands
(1), file formats (5) and macro packages (7)\&. The sectioning commands in a
manpage are \fBnot\fP \f(CW(n)sect\fP etc\&., but \f(CWmanpage\&.\&.\&.()\fP\&. The order of the
sections in a manpage \fBmust\fP be: \f(CWmanpagename\fP, \f(CWmanpagesynopsis\fP,
\f(CWmanpagedescription\fP, \f(CWmanpageoptions\fP, \f(CWmanpagefiles\fP,
\f(CWmanpageseealso\fP, \f(CWmanpagediagnostics\fP, \f(CWmanpagebugs\fP,
\f(CWmanpageauthor\fP\&. Optional extra sections can be added with
\f(CWmanpagesection\fP\&.
.IP "\f(CWmanpageauthor()\fP" 
Starts the AUTHOR entry in a \f(CWmanpage\fP document\&. Must be the last section
of a \f(CWmanpage\fP\&.
.IP "\f(CWmanpagebugs()\fP" 
Starts the BUGS entry in a \f(CWmanpage\fP document\&.
.IP "\f(CWmanpagedescription()\fP" 
Starts the DESCRIPTION entry in a \f(CWmanpage\fP document\&.
.IP "\f(CWmanpagediagnostics()\fP" 
Starts the DIAGNOSTICS entry in a \f(CWmanpage\fP document\&.
.IP "\f(CWmanpagefiles()\fP" 
Starts the FILES entry in a \f(CWmanpage\fP document\&.
.IP "\f(CWmanpagename(name)(short description)\fP" 
Starts the NAME entry in a \f(CWmanpage\fP document\&. The short description is
used by, e\&.g\&., the \f(CWwhatis\fP database\&.
.IP "\f(CWmanpageoptions()\fP" 
Starts the OPTIONS entry in a \f(CWmanpage\fP document\&.
.IP "\f(CWmanpageseealso()\fP" 
Starts the SEE ALSO entry in a \f(CWmanpage\fP document\&.
.IP "\f(CWmanpagesection(SECTIONNAME)\fP" 
Inserts a non-required section named \f(CWSECTIONNAME\fP in a \f(CWmanpage\fP
document\&. This macro can be used to augment `standard\' manual pages with extra
sections, e\&.g\&., EXAMPLES\&. \fBNote that\fP the name of the extra section should
appear in upper case, which is consistent with the normal typesetting of
manual pages\&.
.IP "\f(CWmanpagesynopsis()\fP" 
Starts the SYNOPSIS entry in a \f(CWmanpage\fP document\&.
.IP "\f(CWmscommand(cmd)\fP" 
Writes \f(CWcmd\fP to the output when converting to ms\&. The \f(CWcmd\fP is not
further expanded by YODL\&.
.IP "\f(CWnchapter(title)\fP" 
Starts a chapter (in a \f(CWbook\fP or \f(CWreport\fP) without generating a 
number before the title and without placing an entry for the chapter in 
the table of contents\&.
.IP "\f(CWnl()\fP" 
Forces a newline; i\&.e\&., breaks the current line in two\&.
.IP "\f(CWnotableofcontents()\fP" 
Prevents the generation of a table of contents\&. This is default in, e\&.g\&., 
\f(CWmanpage\fP and \f(CWplainhtml\fP documents\&. When present, this option \fBmust\fP
appear before stating the document type with \f(CWarticle\fP, \f(CWreport\fP
etc\&.\&.
.IP "\f(CWnosloppyhfuzz()\fP" 
By default, LaTeX output contains commands that cause it to shut up about
hboxes that are less than 4pt overfull\&. When \f(CWnosloppyhfuzz()\fP appears
before stating the document type, LaTeX complaints are `vanilla\'\&.
.IP "\f(CWnpart(title)\fP" 
Starts a part in a \f(CWbook\fP document, but without numbering it and without
entering the title of the part in the table of contents\&.
.IP "\f(CWnsect(title)\fP" 
Starts a section, but does not generate a number before the \f(CWtitle\fP nor 
an entry in the table of contents\&. Further sectioning commands are 
\f(CWnsubsect\fP, \f(CWnsubsubsect\fP and \f(CWnsubsubsubsect\fP\&.
.IP "\f(CWnsubsect(title)\fP" 
Starts a non-numbered subsection\&.
.IP "\f(CWnsubsubsect(title)\fP" 
Starts a non-numbered sub-subsection\&.
.IP "\f(CWnsubsubsect(title)\fP" 
Starts a non-numbered sub-sub-subsection\&.
.IP "\f(CWpart(title)\fP" 
Starts a new part in a \f(CWbook\fP document\&.
.IP "\f(CWplainhtml(title)\fP" 
Starts a document for only a plain HTML conversion\&. Not available in 
other output formats\&. Similar to \f(CWarticle\fP, except that an author- and 
date field are not needed\&.
.IP "\f(CWquote(text)\fP" 
Sets the text as a quotation\&. Usually, the text is indented, depending on the
output format\&.
.IP "\f(CWredef(macro)(nrofarguments)(redefinition)\fP" 
Defines macro \f(CWmacro\fP to expand to \f(CWredefinition\fP\&.
Similar to \f(CWdef\fP, but any pre-existing definition is overruled\&. This command
is a shorthand for \f(CWredefinemacro\fP\&.
.IP "\f(CWredefinemacro(nrofargs)(redefinition)\fP" 
Defines macro \f(CWmacro\fP to expand to \f(CWredefinition\fP\&.
Similar to \f(CWdef\fP, but any pre-existing definition is overruled\&. Use
\f(CWARG\fP\fIx\fP in the redefinition part to indicate where the arguments should
be pasted\&. E\&.g\&., \f(CWARG1\fP places the first argument, \f(CWARG2\fP the second
argument, etc\&.\&.
.IP "\f(CWref(labelname)\fP" 
Sets the reference for \f(CWlabelname\fP\&. Use \f(CWlabel\fP to define a label\&.
.IP "\f(CWreport(title)(author)(date)\fP" 
Starts a report type document\&. The top-level sectioning command in a report
is \f(CWchapter\fP\&.
.IP "\f(CWroffcmd(dotcmd)(sameline)(secondline)(thirdline)\fP" 
Sets a t/nroff command that starts with a dot, on its own line\&. The arguments
are: \f(CWdotcmd\fP - the command itself, e\&.g\&., \f(CW\&.IP\fP; \f(CWsameline\fP - when not
empty, set following the \f(CWdotcmd\fP on the same line; \f(CWsecondline\fP - when
not empty, set on the next line; \f(CWthirdline\fP - when not empty, set on the
third line\&. Note that \f(CWdotcmd\fP and \f(CWthirdline\fP are not further expanded by
YODL, the other arguments are\&.
.IP "\f(CWsect(title)\fP" 
Starts a new section\&.
.IP "\f(CWsgmlcommand(cmd)\fP" 
Writes \f(CWcmd\fP to the output when converting to SGML\&. The \f(CWcmd\fP is not 
further expanded by YODL\&.
.IP "\f(CWsgmltag(tag)(onoff)\fP" 
Similar to \f(CWhtmltag\fP, but used in the SGML converter\&.
.IP "\f(CWstandardlayout()\fP" 
Enables the default LaTeX layout\&. When this macro is absent, then the
first lines of paragraphs are not indented and the space between
paragraphs is somewhat larger\&. The \f(CWstandardlayout()\fP directive must appear
\fBbefore\fP stating the document type as \f(CWarticle\fP, \f(CWreport\fP, etc\&.\&.
.IP "\f(CWstartcenter()\fP" 
Starts centered text\&. Use \f(CWendcenter()\fP to stop centering text\&.
.IP "\f(CWstartdit()\fP" 
Starts a descriptive list\&. Use \f(CWdit(item)\fP to set items in the list, and
use \f(CWenddit()\fP to end the list\&.
.IP "\f(CWstarteit()\fP" 
Starts an enumerated list\&. Use \f(CWeit()\fP in the list to indicate items, and
use \f(CWendeit()\fP to end the list\&.
.IP "\f(CWstartit()\fP" 
Starts an itemized list\&. Use \f(CWit()\fP in the list to indicate items, and use
\f(CWendit()\fP to end the list\&.
.IP "\f(CWsubsect(title)\fP" 
Starts a new subsection\&. Other sectioning commands are
\f(CWsubsubsect\fP and \f(CWsubsubsubsect\fP\&.
.IP "\f(CWsubsubsect(title)\fP" 
Starts a sub-subsection\&.
.IP "\f(CWsubsubsubsect(title)\fP" 
Starts a sub-sub-subsection\&.
.IP "\f(CWtt(text)\fP" 
Sets \f(CWtext\fP in teletype font, and prevents it from being expanded\&.
For unbalanced parameter lists, use \f(CWCHAR(40)\fP to get
\f(CW(\fP and \f(CWCHAR(41)\fP to get \f(CW)\fP\&.
.IP "\f(CWtxtcommand(cmd)\fP" 
Writes \f(CWcmd\fP to the output when converting to ASCII\&. The \f(CWcmd\fP 
is not further expanded by YODL\&.
.IP "\f(CWurl(description)(locator)\fP" 
In LaTeX documents the \f(CWdescription\fP is sent to the output\&. For HTML,
a link is created with the descriptive text \f(CWdescription\fP and pointing
to \f(CWlocator\fP\&. The \f(CWlocator\fP should be the full URL, including
service; e\&.g, \f(CWhttp://www\&.icce\&.rug\&.nl\fP, but excluding the double
quotes that are necessary in plain HTML\&. Use the macro \f(CWlink\fP to create
links within the same document\&. For other formats, something like
\fIdescription [locator]\fP will appear\&.
.IP "\f(CWverb(text)\fP" 
Sets \f(CWtext\fP in verbatim mode: not subject to macro expansion or
character table expansion\&. The text appears literally on the output,
usually in a teletype font (that depends on the output format)\&. This
macro is for larger chunks, e\&.g\&., listings\&. For unbalanced parameter 
lists, use \f(CWCHAR(40)\fP to get \f(CW(\fP and \f(CWCHAR(41)\fP 
to get \f(CW)\fP\&.
.IP "\f(CWwhenhtml(text)\fP" 
Sends \f(CWtext\fP to the output when in HTML conversion mode\&. The text is 
further expanded if necessary\&.
.IP "\f(CWwhenlatex(text)\fP" 
Sends \f(CWtext\fP to the output when in LaTeX conversion mode\&. The text is 
further expanded if necessary\&.
.IP "\f(CWwhenman(text)\fP" 
Sends \f(CWtext\fP to the output when in man conversion mode\&. The text is 
further expanded if necessary\&.
.IP "\f(CWwhenms(text)\fP" 
Sends \f(CWtext\fP to the output when in ms conversion mode\&. The text is further
expanded if necessary\&.
.IP "\f(CWwhensgml(text)\fP" 
Sends \f(CWtext\fP to the output when in SGML conversion mode\&. The text is 
further expanded if necessary\&.
.IP "\f(CWwhentxt(text)\fP" 
Sends \f(CWtext\fP to the output when in ASCII conversion mode\&. The text is 
further expanded if necessary\&.
.IP 
.PP 
.PP 
.SH "OPTIONS" 
No options are relevant in respect to the macros\&.
.PP 
.SH "FILES" 
The files in \fB/usr/local/lib/yodl/\fP define the macro package of 
the converter\&. The scripts \fByodl2tex\fP, \fByodl2html\fP, 
\fByodl2man\fP etc\&. run the conversions\&.
.PP 
.SH "SEE ALSO" 
.PP 
.IP o 
\fByodl\fP: the main YODL converter
.IP o 
\fByodlmanpage\fP: more detailed description of the
\f(CWmanpage\fP format
.IP o 
\fByodlconverters\fP: divers converters for divers output
formats 
.IP 
.SH "DIAGNOSTICS" 
Error messages and warnings are printed to stderr\&. There are too
many warnings or error messages to enumerate, but they should be
self-explanatory\&.
.IP 
.SH "BUGS" 
The macro package may contain bugs, but I\'m working on it\&. 
Furthermore, the macro package may not be complete\&.
.IP 
.SH "AUTHOR" 
Karel Kubat (karel@icce\&.rug\&.nl)
